@@ -379,7 +379,7 @@ TQString NetworkInterface::getGatewayOfDefaultInterface()
 		while ( !stream.atEnd() )
 		{
 			line = stream.readLine(); // line of text excluding '\n' and replace all white chars with one blank
-			std::cout << "line: \"" << line << "\"" << "\n";
+			std::cout << "line: \"" << line.local8Bit() << "\"" << "\n";
 			if (line.simplifyWhiteSpace().section( ' ', 1, 1 ) == "00000000" )
 			{
 					struct sockaddr_in name;
@@ -436,7 +436,7 @@ bool NetworkInterface::inSameNetwork(TQString ip1,TQString Netmask1,TQString ip2
 	}
 	else
 	{
-		std::cout << "ip1: " << ip1.section( '.', 0, 2 ) << " , ip2: " << ip2.section( '.', 0, 2 ) << std::endl;
+		std::cout << "ip1: " << ip1.section( '.', 0, 2 ).local8Bit() << " , ip2: " << ip2.section( '.', 0, 2 ).local8Bit() << std::endl;
 		if (ip1.section( '.', 0, 2 ) == ip2.section( '.', 0, 2 ))
 		{
 			if (Netmask1 == Netmask2)
@@ -562,3 +562,5 @@ void NetworkInterface::readFromStderr_interfaceip()
                 //std::cerr << "dbg err: " << line << std::endl;
         }
 }
+
+#include "networkinterface.moc"
